
# Type: disease to exposure association_object




URI: [biolink:disease_to_exposure_association_object](https://w3id.org/biolink/vocab/disease_to_exposure_association_object)


## Domain and Range

[DiseaseToExposureAssociation](DiseaseToExposureAssociation.md) ->  <sub>REQ</sub> [ExposureEvent](ExposureEvent.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [DiseaseToExposureAssociation](DiseaseToExposureAssociation.md)
